@@ -1,7 +1,9 @@
 package WebService::Solr;
 
-use Any::Moose;
+use Moo;
 
+use Types::Standard qw(InstanceOf Object Bool HashRef Maybe);
+use Scalar::Util qw(blessed);
 use Encode qw(encode);
 use URI;
 use LWP::UserAgent;
@@ -14,28 +16,33 @@ use XML::Easy::Text ();
 
 has 'url' => (
     is      => 'ro',
-    isa     => 'URI',
+    isa     => InstanceOf['URI'],
     default => sub { URI->new( 'http://localhost:8983/solr' ) }
 );
 
 has 'agent' =>
-    ( is => 'ro', isa => 'Object', default => sub { LWP::UserAgent->new } );
+    ( is => 'ro', isa => Object, default => sub { LWP::UserAgent->new } );
 
-has 'autocommit' => ( is => 'ro', isa => 'Bool', default => 1 );
+has 'autocommit' => ( is => 'ro', isa => Bool, default => 1 );
 
 has 'default_params' => (
     is         => 'ro',
-    isa        => 'HashRef',
-    auto_deref => 1,
+    isa        => HashRef,
     default    => sub { { wt => 'json' } }
 );
 
+around default_params => sub {
+    my ($orig, $self, @args) = @_;
+    my $ret = $self->$orig(@args);
+    return wantarray ? %$ret : $ret;
+};
+
 has 'last_response' => (
     is  => 'rw',
-    isa => 'Maybe[WebService::Solr::Response]',
+    isa => Maybe[InstanceOf['WebService::Solr::Response']],
 );
 
-our $VERSION = '0.23';
+our $VERSION = '0.40';
 
 sub BUILDARGS {
     my ( $self, $url, $options ) = @_;
@@ -197,9 +204,7 @@ sub _send_update {
     return $self->last_response;
 }
 
-no Any::Moose;
-
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 
@@ -262,7 +267,7 @@ listed in the L<ACCESSORS|/"ACCESSORS"> section.
 
 =head2 BUILDARGS( @args )
 
-A Moose override to allow our custom constructor.
+A Moo override to allow our custom constructor.
 
 =head2 add( $doc|\@docs, \%options )
 
@@ -329,6 +334,9 @@ and a copyright year of 2011 or 2012:
 The filter queries are typically added when drilling down into search
 results and selecting a facet to drill into.
 
+In order to enable facets, the option C<facet =E<gt> "on"> must be passed.
+Facet options are detailed in the wiki (https://wiki.apache.org/solr/SimpleFacetParameters).
+
 =head2 auto_suggest( \%options )
 
 Get suggestions from a list of terms for a given field. The Solr wiki has
@@ -397,7 +405,7 @@ Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2014 National Adult Literacy Database
+Copyright 2008-2016 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
