@@ -1,12 +1,14 @@
 package WebService::Solr::Query;
 
-use Any::Moose;
+use Moo;
+
+use Types::Standard qw(ArrayRef);
 
 use overload q("") => 'stringify';
 
 my $escape_chars = quotemeta( '+-&|!(){}[]^"~*?:\\' );
 
-has 'query' => ( is => 'ro', isa => 'ArrayRef', default => sub { [] } );
+has 'query' => ( is => 'ro', isa => ArrayRef, default => sub { [] } );
 
 use constant D => 0;
 
@@ -276,9 +278,7 @@ sub __dumper {
     return Data::Dumper::Dumper( @_ );
 }
 
-no Any::Moose;
-
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 
@@ -427,7 +427,7 @@ Debugging constant, default: off.
 
 =head2 BUILDARGS
 
-Moose method to handle input to C<new()>.
+Moo method to handle input to C<new()>.
 
 =head1 SEE ALSO
 
@@ -447,7 +447,7 @@ Jos Boumans E<lt>kane@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2014 National Adult Literacy Database
+Copyright 2008-2016 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
